
TODO: TODO_08_25_32_95: redesign `class_to_collection_map`

It makes little sense, it should make more.

It was created for the single "technical" purpose - to FS_56_43_05_79 search diff collection.
Yes, it served its initial purpose, but:

*   It is not needed in most of the cases.

    Not needed because combination of these 2 factors eliminates the need to specify it:

    *   Most of the time, each `envelope_class` has to be loaded into its own `collection_name` - why not?
    *   Loading multiple `envelope_class`-es into single `collection_name` combines their sets of `index_prop`-s.

    In short, we can always rely on default mapping where `collection_name` = `envelope_class`.

